==> downloads.php?file=source%2FTrueCrypt+7.0+Source.zip: Mount/Resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by Mount.rc
//
#define IDR_MOUNT_TLB                   1
#define IDD_MOUNT_DLG                   101
#define IDD_PASSWORDCHANGE_DLG          102
#define IDB_DRIVEICON                   103
#define IDD_PASSWORD_DLG                104
#define IDB_DRIVEICON_MASK              105
#define IDR_MENU                        106
#define IDD_PREFERENCES_DLG             107
#define IDD_VOLUME_PROPERTIES           108
#define IDR_MOUNT_RSRC_HEADER           109
#define IDS_UACSTRING                   110
#define IDB_LOGO_288DPI                 111
#define IDB_LOGO_96DPI                  112
#define IDB_SYS_DRIVEICON               113
#define IDB_SYS_DRIVEICON_MASK          114
#define IDD_TOKEN_PREFERENCES           115
#define IDD_SYSENC_SETTINGS             116
#define IDD_FAVORITE_VOLUMES            117
#define IDC_PREF_MOUNT_READONLY         1000
#define IDC_PREF_MOUNT_REMOVABLE        1001
#define IDC_VERIFY                      1002
#define IDC_PREF_BKG_TASK_ENABLE        1003
#define IDC_OLD_PASSWORD                1004
#define IDC_CACHE                       1005
#define IDC_NO_HISTORY                  1006
#define IDC_DRIVELIST                   1007
#define IDC_PREF_OPEN_EXPLORER          1008
#define IDC_ENABLE_KEYFILES             1009
#define IDC_VOLUME_PROPERTIES_LIST      1010
#define IDC_PREF_CLOSE_DISMOUNTED_WINDOWS 1011
#define IDC_ENABLE_NEW_KEYFILES         1012
#define IDC_PRESERVE_TIMESTAMPS         1013
#define IDC_PREF_WIPE_CACHE_ON_EXIT     1014
#define IDC_PKCS5_PRF_ID                1015
#define IDC_PREF_CACHE_PASSWORDS        1016
#define IDC_DIRECTORY                   1017
#define IDC_PREF_DISMOUNT_LOGOFF        1018
#define IDC_BROWSE_DIRS                 1019
#define IDC_PREF_DISMOUNT_INACTIVE      1020
#define IDC_AUTORUN_DISABLE             1021
#define IDC_AUTORUN_START               1022
#define IDC_BENCHMARK                   1023
#define IDC_AUTORUN_MOUNT               1024
#define IDC_VOLUME_NAME                 1025
#define IDC_COPY_WIZARD                 1026
#define IDC_MOUNT_OPTIONS               1027
#define IDT_TRAVELER_MOUNT              1028
#define IDT_MOUNT_LETTER                1029
#define IDT_MOUNT_SETTINGS              1030
#define IDC_KEY_FILES                   1031
#define IDC_NEW_KEYFILES                1032
#define IDC_KEYFILES                    1033
#define IDC_VOLUME                      1034
#define IDC_PASSWORD                    1035
#define IDC_BROWSE_FILES                1036
#define IDC_SELECT_DEVICE               1037
#define IDC_CREATE_VOLUME               1038
#define IDC_VOLUME_TOOLS                1039
#define IDC_WIPE_CACHE                  1040
#define IDC_MOUNTALL                    1041
#define IDD_TRAVELER_DLG                1042
#define IDC_SELECT_FILE                 1043
#define IDD_HOTKEYS_DLG                 1044
#define IDC_VOLUME_PROPERTIES           1045
#define IDT_FILE_SETTINGS               1046
#define IDD_PERFORMANCE_SETTINGS        1047
#define IDT_AUTORUN                     1048
#define IDT_TRAVEL_INSERTION            1049
#define IDT_TRAVEL_ROOT                 1050
#define IDT_VOLUME                      1051
#define IDT_PASSWORD                    1052
#define IDT_CURRENT                     1053
#define IDT_NEW                         1054
#define IDT_NEW_PASSWORD                1055
#define IDT_CONFIRM_PASSWORD            1056
#define IDT_PKCS5_PRF                   1057
#define IDT_PW_CACHE_OPTIONS            1058
#define IDT_DEFAULT_MOUNT_OPTIONS       1059
#define IDT_WINDOWS_RELATED_SETTING     1060
#define IDC_CREATE                      1061
#define IDC_EXIT                        1062
#define IDC_TRAVEL_OPEN_EXPLORER        1063
#define IDC_TRAV_CACHE_PASSWORDS        1064
#define IDC_UNMOUNTALL                  1065
#define IDT_TASKBAR_ICON                1066
#define IDT_AUTO_DISMOUNT               1067
#define IDC_PREF_FORCE_AUTO_DISMOUNT    1068
#define IDC_PREF_DISMOUNT_INACTIVE_TIME 1069
#define IDT_MINUTES                     1070
#define IDC_PREF_DISMOUNT_SCREENSAVER   1071
#define IDC_PREF_DISMOUNT_POWERSAVING   1072
#define IDT_AUTO_DISMOUNT_ON            1073
#define IDC_PREF_WIPE_CACHE_ON_AUTODISMOUNT 1074
#define IDC_CLOSE_BKG_TASK_WHEN_NOVOL   1075
#define IDC_MORE_INFO_ON_HW_ACCELERATION 1076
#define IDT_LOGON                       1077
#define IDC_MORE_INFO_ON_THREAD_BASED_PARALLELIZATION 1078
#define IDC_PREF_LOGON_START            1079
#define IDC_PREF_LOGON_MOUNT_DEVICES    1080
#define IDC_SHOW_PASSWORD_CHPWD_NEW     1081
#define IDC_DISMOUNT_CONFIRM_MSG_BOX    1082
#define IDC_SHOW_PASSWORD_CHPWD_ORI     1083
#define IDC_DISMOUNT_CONFIRM_PLAY_SOUND 1084
#define IDC_HOTKEY_ASSIGN               1085
#define IDC_HOTKEY_REMOVE               1086
#define IDC_HOTKEY_KEY                  1087
#define IDT_HOTKEY_KEY                  1088
#define IDC_HOTKEY_LIST                 1089
#define IDC_RESET_HOTKEYS               1090
#define IDT_DISMOUNT_ACTION             1091
#define IDT_ASSIGN_HOTKEY               1092
#define IDC_HK_MOD_SHIFT                1093
#define IDC_HK_MOD_CTRL                 1094
#define IDC_HK_MOD_ALT                  1095
#define IDC_HK_MOD_WIN                  1096
#define IDC_SHOW_PASSWORD               1097
#define IDC_LOGO                        1098
#define IDT_PKCS11_LIB_PATH             1099
#define IDC_PKCS11_MODULE               1100
#define IDC_SELECT_PKCS11_MODULE        1101
#define IDC_AUTO_DETECT_PKCS11_MODULE   1102
#define IDC_CLOSE_TOKEN_SESSION_AFTER_MOUNT 1103
#define IDT_SECURITY_OPTIONS            1104
#define IDC_DISABLE_BOOT_LOADER_OUTPUT  1105
#define IDC_ALLOW_ESC_PBA_BYPASS        1106
#define IDC_CUSTOM_BOOT_LOADER_MESSAGE  1107
#define IDC_BOOT_LOADER_CACHE_PASSWORD  1108
#define IDC_MORE_SETTINGS               1109
#define IDT_CUSTOM_BOOT_LOADER_MESSAGE  1110
#define IDC_CUSTOM_BOOT_LOADER_MESSAGE_HELP 1111
#define IDT_BOOT_LOADER_SCREEN_OPTIONS  1112
#define IDT_PKCS11_LIB_HELP             1113
#define IDT_ACCELERATION_OPTIONS        1114
#define IDC_ENABLE_HARDWARE_ENCRYPTION  1115
#define IDC_FAVORITE_VOLUMES_LIST       1116
#define IDC_FAVORITE_MOUNT_READONLY     1117
#define IDC_FAVORITE_MOUNT_REMOVABLE    1118
#define IDC_FAVORITE_MOUNT_ON_ARRIVAL   1119
#define IDC_FAVORITE_LABEL              1120
#define IDT_FAVORITE_LABEL              1121
#define IDC_FAVORITE_MOUNT_ON_LOGON     1122
#define IDC_FAVORITE_DISABLE_HOTKEY     1123
#define IDC_FAVORITE_MOVE_UP            1124
#define IDC_FAVORITE_MOVE_DOWN          1125
#define IDC_FAVORITE_REMOVE             1126
#define IDT_HW_AES_SUPPORTED_BY_CPU     1127
#define IDC_FAVORITE_OPEN_EXPLORER_WIN_ON_MOUNT 1128
#define IDC_HW_AES_SUPPORTED_BY_CPU     1129
#define IDC_LIMIT_ENC_THREAD_POOL       1130
#define IDC_ENCRYPTION_FREE_CPU_COUNT   1131
#define IDT_PARALLELIZATION_OPTIONS     1132
#define IDT_LIMIT_ENC_THREAD_POOL_NOTE  1133
#define IDC_FAV_VOL_OPTIONS_GROUP_BOX   1134
#define IDC_FAVORITES_HELP_LINK         1135
#define IDC_FAV_VOL_OPTIONS_GLOBAL_SETTINGS_BOX 1136
#define IDM_HELP                        40001
#define IDM_ABOUT                       40002
#define IDM_UNMOUNT_VOLUME              40003
#define IDM_CLEAR_HISTORY               40004
#define IDM_FORUMS                      40005
#define IDM_BENCHMARK                   40006
#define IDM_TRAVELER                    40007
#define IDM_MOUNT_VOLUME_OPTIONS        40008
#define IDM_FAQ                         40009
#define IDM_REFRESH_DRIVE_LETTERS       40010
#define IDM_DEFAULT_KEYFILES            40011
#define IDM_WEBSITE                     40012
#define IDM_MOUNTALL                    40013
#define IDM_UNMOUNTALL                  40014
#define IDM_MOUNT_VOLUME                40015
#define IDM_CHANGE_PASSWORD             40016
#define IDM_VOLUME_WIZARD               40017
#define IDM_CREATE_VOLUME               40018
#define IDM_WIPE_CACHE                  40019
#define IDM_PREFERENCES                 40020
#define IDM_LICENSE                     40021
#define IDM_SELECT_FILE                 40022
#define IDM_SELECT_DEVICE               40023
#define IDM_VOLUME_PROPERTIES           40024
#define IDM_LANGUAGE                    40025
#define IDM_MOUNT_FAVORITE_VOLUMES      40026
#define IDM_BACKUP_VOL_HEADER           40027
#define IDM_RESTORE_VOL_HEADER          40028
#define IDM_HOTKEY_SETTINGS             40029
#define IDM_TC_DOWNLOADS                40030
#define IDM_NEWS                        40031
#define IDM_BUGREPORT                   40032
#define IDM_CONTACT                     40033
#define IDM_VERSION_HISTORY             40034
#define IDM_HOMEPAGE                    40035
#define IDM_TEST_VECTORS                40036
#define IDM_ADD_REMOVE_VOL_KEYFILES     40037
#define IDM_REMOVE_ALL_KEYFILES_FROM_VOL 40038
#define IDM_CHANGE_HEADER_KEY_DERIV_ALGO 40039
#define IDM_KEYFILE_GENERATOR           40040
#define IDM_ONLINE_TUTORIAL             40041
#define IDM_ONLINE_HELP                 40042
#define IDM_DONATIONS                   40043
#define IDM_CHANGE_SYS_HEADER_KEY_DERIV_ALGO 40044
#define IDM_CHANGE_SYS_PASSWORD         40045
#define IDM_CREATE_RESCUE_DISK          40046
#define IDM_PERMANENTLY_DECRYPT_SYS     40047
#define IDM_VERIFY_RESCUE_DISK          40048
#define IDM_SYSTEM_ENCRYPTION_STATUS    40049
#define IDM_ENCRYPT_SYSTEM_DEVICE       40050
#define IDM_SYSENC_RESUME               40051
#define IDM_MOUNT_SYSENC_PART_WITHOUT_PBA 40052
#define IDM_CREATE_HIDDEN_OS            40053
#define IDM_TOKEN_PREFERENCES           40054
#define IDM_CLOSE_ALL_TOKEN_SESSIONS    40055
#define IDM_SYS_ENC_SETTINGS            40056
#define IDM_SYSENC_SETTINGS             40057
#define IDM_RESUME_INTERRUPTED_PROC     40058
#define IDM_MANAGE_TOKEN_KEYFILES       40059
#define IDM_SYS_FAVORITES_SETTINGS      40060
#define IDM_ORGANIZE_FAVORITES          40061
#define IDM_ORGANIZE_SYSTEM_FAVORITES   40062
#define IDM_ADD_VOLUME_TO_FAVORITES     40063
#define IDM_ADD_VOLUME_TO_SYSTEM_FAVORITES 40064
#define IDM_PERFORMANCE_SETTINGS        40065
#define IDM_ANALYZE_SYSTEM_CRASH        40066

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        118
#define _APS_NEXT_COMMAND_VALUE         40067
#define _APS_NEXT_CONTROL_VALUE         1137
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> downloads.php?file=source%2FTrueCrypt+7.1a+Source.zip: Mount/Resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by Mount.rc
//
#define IDR_MOUNT_TLB                   1
#define IDD_MOUNT_DLG                   101
#define IDD_PASSWORDCHANGE_DLG          102
#define IDB_DRIVEICON                   103
#define IDD_PASSWORD_DLG                104
#define IDB_DRIVEICON_MASK              105
#define IDR_MENU                        106
#define IDD_PREFERENCES_DLG             107
#define IDD_VOLUME_PROPERTIES           108
#define IDR_MOUNT_RSRC_HEADER           109
#define IDS_UACSTRING                   110
#define IDB_LOGO_288DPI                 111
#define IDB_LOGO_96DPI                  112
#define IDB_SYS_DRIVEICON               113
#define IDB_SYS_DRIVEICON_MASK          114
#define IDD_TOKEN_PREFERENCES           115
#define IDD_SYSENC_SETTINGS             116
#define IDD_FAVORITE_VOLUMES            117
#define IDC_PREF_MOUNT_READONLY         1000
#define IDC_PREF_MOUNT_REMOVABLE        1001
#define IDC_VERIFY                      1002
#define IDC_PREF_BKG_TASK_ENABLE        1003
#define IDC_OLD_PASSWORD                1004
#define IDC_CACHE                       1005
#define IDC_NO_HISTORY                  1006
#define IDC_DRIVELIST                   1007
#define IDC_PREF_OPEN_EXPLORER          1008
#define IDC_ENABLE_KEYFILES             1009
#define IDC_VOLUME_PROPERTIES_LIST      1010
#define IDC_PREF_USE_DIFF_TRAY_ICON_IF_VOL_MOUNTED 1011
#define IDC_ENABLE_NEW_KEYFILES         1012
#define IDC_PRESERVE_TIMESTAMPS         1013
#define IDC_PREF_WIPE_CACHE_ON_EXIT     1014
#define IDC_PKCS5_PRF_ID                1015
#define IDC_PREF_CACHE_PASSWORDS        1016
#define IDC_DIRECTORY                   1017
#define IDC_PREF_DISMOUNT_LOGOFF        1018
#define IDC_BROWSE_DIRS                 1019
#define IDC_PREF_DISMOUNT_INACTIVE      1020
#define IDC_AUTORUN_DISABLE             1021
#define IDC_AUTORUN_START               1022
#define IDC_BENCHMARK                   1023
#define IDC_AUTORUN_MOUNT               1024
#define IDC_VOLUME_NAME                 1025
#define IDC_COPY_WIZARD                 1026
#define IDC_MOUNT_OPTIONS               1027
#define IDT_TRAVELER_MOUNT              1028
#define IDT_MOUNT_LETTER                1029
#define IDT_MOUNT_SETTINGS              1030
#define IDC_KEY_FILES                   1031
#define IDC_NEW_KEYFILES                1032
#define IDC_KEYFILES                    1033
#define IDC_VOLUME                      1034
#define IDC_PASSWORD                    1035
#define IDC_BROWSE_FILES                1036
#define IDC_SELECT_DEVICE               1037
#define IDC_CREATE_VOLUME               1038
#define IDC_VOLUME_TOOLS                1039
#define IDC_WIPE_CACHE                  1040
#define IDC_MOUNTALL                    1041
#define IDD_TRAVELER_DLG                1042
#define IDC_SELECT_FILE                 1043
#define IDD_HOTKEYS_DLG                 1044
#define IDC_VOLUME_PROPERTIES           1045
#define IDT_FILE_SETTINGS               1046
#define IDD_PERFORMANCE_SETTINGS        1047
#define IDT_AUTORUN                     1048
#define IDT_TRAVEL_INSERTION            1049
#define IDT_TRAVEL_ROOT                 1050
#define IDT_VOLUME                      1051
#define IDT_PASSWORD                    1052
#define IDT_CURRENT                     1053
#define IDT_NEW                         1054
#define IDT_NEW_PASSWORD                1055
#define IDT_CONFIRM_PASSWORD            1056
#define IDT_PKCS5_PRF                   1057
#define IDT_PW_CACHE_OPTIONS            1058
#define IDT_DEFAULT_MOUNT_OPTIONS       1059
#define IDT_WINDOWS_RELATED_SETTING     1060
#define IDC_CREATE                      1061
#define IDC_EXIT                        1062
#define IDC_TRAVEL_OPEN_EXPLORER        1063
#define IDC_TRAV_CACHE_PASSWORDS        1064
#define IDC_UNMOUNTALL                  1065
#define IDT_TASKBAR_ICON                1066
#define IDT_AUTO_DISMOUNT               1067
#define IDC_PREF_FORCE_AUTO_DISMOUNT    1068
#define IDC_PREF_DISMOUNT_INACTIVE_TIME 1069
#define IDT_MINUTES                     1070
#define IDC_PREF_DISMOUNT_SCREENSAVER   1071
#define IDC_PREF_DISMOUNT_POWERSAVING   1072
#define IDT_AUTO_DISMOUNT_ON            1073
#define IDC_PREF_WIPE_CACHE_ON_AUTODISMOUNT 1074
#define IDC_CLOSE_BKG_TASK_WHEN_NOVOL   1075
#define IDC_MORE_INFO_ON_HW_ACCELERATION 1076
#define IDT_LOGON                       1077
#define IDC_MORE_INFO_ON_THREAD_BASED_PARALLELIZATION 1078
#define IDC_PREF_LOGON_START            1079
#define IDC_PREF_LOGON_MOUNT_DEVICES    1080
#define IDC_SHOW_PASSWORD_CHPWD_NEW     1081
#define IDC_HK_DISMOUNT_BALLOON_TOOLTIP 1082
#define IDC_SHOW_PASSWORD_CHPWD_ORI     1083
#define IDC_HK_DISMOUNT_PLAY_SOUND      1084
#define IDC_HOTKEY_ASSIGN               1085
#define IDC_HOTKEY_REMOVE               1086
#define IDC_HOTKEY_KEY                  1087
#define IDT_HOTKEY_KEY                  1088
#define IDC_HOTKEY_LIST                 1089
#define IDC_RESET_HOTKEYS               1090
#define IDT_DISMOUNT_ACTION             1091
#define IDT_ASSIGN_HOTKEY               1092
#define IDC_HK_MOD_SHIFT                1093
#define IDC_HK_MOD_CTRL                 1094
#define IDC_HK_MOD_ALT                  1095
#define IDC_HK_MOD_WIN                  1096
#define IDC_SHOW_PASSWORD               1097
#define IDC_LOGO                        1098
#define IDT_PKCS11_LIB_PATH             1099
#define IDC_PKCS11_MODULE               1100
#define IDC_SELECT_PKCS11_MODULE        1101
#define IDC_AUTO_DETECT_PKCS11_MODULE   1102
#define IDC_CLOSE_TOKEN_SESSION_AFTER_MOUNT 1103
#define IDT_SECURITY_OPTIONS            1104
#define IDC_DISABLE_BOOT_LOADER_OUTPUT  1105
#define IDC_ALLOW_ESC_PBA_BYPASS        1106
#define IDC_CUSTOM_BOOT_LOADER_MESSAGE  1107
#define IDC_BOOT_LOADER_CACHE_PASSWORD  1108
#define IDC_MORE_SETTINGS               1109
#define IDT_CUSTOM_BOOT_LOADER_MESSAGE  1110
#define IDC_CUSTOM_BOOT_LOADER_MESSAGE_HELP 1111
#define IDT_BOOT_LOADER_SCREEN_OPTIONS  1112
#define IDT_PKCS11_LIB_HELP             1113
#define IDT_ACCELERATION_OPTIONS        1114
#define IDC_ENABLE_HARDWARE_ENCRYPTION  1115
#define IDC_FAVORITE_VOLUMES_LIST       1116
#define IDC_FAVORITE_MOUNT_READONLY     1117
#define IDC_FAVORITE_MOUNT_REMOVABLE    1118
#define IDC_FAVORITE_MOUNT_ON_ARRIVAL   1119
#define IDC_FAVORITE_LABEL              1120
#define IDT_FAVORITE_LABEL              1121
#define IDC_FAVORITE_MOUNT_ON_LOGON     1122
#define IDC_FAVORITE_DISABLE_HOTKEY     1123
#define IDC_FAVORITE_MOVE_UP            1124
#define IDC_FAVORITE_MOVE_DOWN          1125
#define IDC_FAVORITE_REMOVE             1126
#define IDT_HW_AES_SUPPORTED_BY_CPU     1127
#define IDC_FAVORITE_OPEN_EXPLORER_WIN_ON_MOUNT 1128
#define IDC_HW_AES_SUPPORTED_BY_CPU     1129
#define IDC_LIMIT_ENC_THREAD_POOL       1130
#define IDC_ENCRYPTION_FREE_CPU_COUNT   1131
#define IDT_PARALLELIZATION_OPTIONS     1132
#define IDT_LIMIT_ENC_THREAD_POOL_NOTE  1133
#define IDC_FAV_VOL_OPTIONS_GROUP_BOX   1134
#define IDC_FAVORITES_HELP_LINK         1135
#define IDC_FAV_VOL_OPTIONS_GLOBAL_SETTINGS_BOX 1136
#define IDM_HELP                        40001
#define IDM_ABOUT                       40002
#define IDM_UNMOUNT_VOLUME              40003
#define IDM_CLEAR_HISTORY               40004
#define IDM_BENCHMARK                   40005
#define IDM_TRAVELER                    40006
#define IDM_MOUNT_VOLUME_OPTIONS        40007
#define IDM_FAQ                         40008
#define IDM_REFRESH_DRIVE_LETTERS       40009
#define IDM_DEFAULT_KEYFILES            40010
#define IDM_WEBSITE                     40011
#define IDM_MOUNTALL                    40012
#define IDM_UNMOUNTALL                  40013
#define IDM_MOUNT_VOLUME                40014
#define IDM_CHANGE_PASSWORD             40015
#define IDM_VOLUME_WIZARD               40016
#define IDM_CREATE_VOLUME               40017
#define IDM_WIPE_CACHE                  40018
#define IDM_PREFERENCES                 40019
#define IDM_LICENSE                     40020
#define IDM_SELECT_FILE                 40021
#define IDM_SELECT_DEVICE               40022
#define IDM_VOLUME_PROPERTIES           40023
#define IDM_LANGUAGE                    40024
#define IDM_MOUNT_FAVORITE_VOLUMES      40025
#define IDM_BACKUP_VOL_HEADER           40026
#define IDM_RESTORE_VOL_HEADER          40027
#define IDM_HOTKEY_SETTINGS             40028
#define IDM_TC_DOWNLOADS                40029
#define IDM_NEWS                        40030
#define IDM_CONTACT                     40031
#define IDM_VERSION_HISTORY             40032
#define IDM_HOMEPAGE                    40033
#define IDM_TEST_VECTORS                40034
#define IDM_ADD_REMOVE_VOL_KEYFILES     40035
#define IDM_REMOVE_ALL_KEYFILES_FROM_VOL 40036
#define IDM_CHANGE_HEADER_KEY_DERIV_ALGO 40037
#define IDM_KEYFILE_GENERATOR           40038
#define IDM_ONLINE_TUTORIAL             40039
#define IDM_ONLINE_HELP                 40040
#define IDM_CHANGE_SYS_HEADER_KEY_DERIV_ALGO 40041
#define IDM_CHANGE_SYS_PASSWORD         40042
#define IDM_CREATE_RESCUE_DISK          40043
#define IDM_PERMANENTLY_DECRYPT_SYS     40044
#define IDM_VERIFY_RESCUE_DISK          40045
#define IDM_SYSTEM_ENCRYPTION_STATUS    40046
#define IDM_ENCRYPT_SYSTEM_DEVICE       40047
#define IDM_SYSENC_RESUME               40048
#define IDM_MOUNT_SYSENC_PART_WITHOUT_PBA 40049
#define IDM_CREATE_HIDDEN_OS            40050
#define IDM_TOKEN_PREFERENCES           40051
#define IDM_CLOSE_ALL_TOKEN_SESSIONS    40052
#define IDM_SYS_ENC_SETTINGS            40053
#define IDM_SYSENC_SETTINGS             40054
#define IDM_RESUME_INTERRUPTED_PROC     40055
#define IDM_MANAGE_TOKEN_KEYFILES       40056
#define IDM_SYS_FAVORITES_SETTINGS      40057
#define IDM_ORGANIZE_FAVORITES          40058
#define IDM_ORGANIZE_SYSTEM_FAVORITES   40059
#define IDM_ADD_VOLUME_TO_FAVORITES     40060
#define IDM_ADD_VOLUME_TO_SYSTEM_FAVORITES 40061
#define IDM_PERFORMANCE_SETTINGS        40062
#define IDM_ANALYZE_SYSTEM_CRASH        40063

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        118
#define _APS_NEXT_COMMAND_VALUE         40064
#define _APS_NEXT_CONTROL_VALUE         1137
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
